import {
  Button,
  message,
  Pagination,
  PaginationProps,
  Popconfirm,
  PopconfirmProps,
  Space,
  Table,
} from "antd";
import { useState } from "react";
const BTable = (props: any) => {
  const { store, dataSource, selectCallback, scroll } = props;
  const [selectedRowKeys, setSelectedRowKeys] = useState<React.Key[]>([]);
  const onSelectChange = (newSelectedRowKeys: React.Key[]) => {
    setSelectedRowKeys(newSelectedRowKeys);
    selectCallback(newSelectedRowKeys);
  };

  const rowSelection = {
    selectedRowKeys,
    onChange: onSelectChange,
  };
  const onShowSizeChange = (current, pageSize) => {
    store.setPages({
      Offset: current,
      Size: pageSize,
    });
  };
  const onChange: PaginationProps["onChange"] = (page) => {
    store.setPages({
      Offset: page,
      Size: 20,
    });
  };
  const cancel: PopconfirmProps["onCancel"] = (e) => {
    message.error("Click on No");
  };
  const confirm: PopconfirmProps["onConfirm"] = (e) => {
    message.success("Click on Yes");
  };
  const actionColumn = {
    title: "操作",
    fixed: "right",
    with: 200,
    render: (any, record) => (
      <Space wrap>
        <Button type="dashed" size="small">
          编辑
        </Button>
        <Popconfirm
          title="Delete the task"
          description="Are you sure to delete this task?"
          onConfirm={confirm}
          onCancel={cancel}
          okText="Yes"
          cancelText="No"
        >
          <Button type="dashed" danger size="small">删除</Button>
        </Popconfirm>
      </Space>
    ),
  };
  return (
    <>
      <Table
        style={{ height: "100%", overflow: "auto" }}
        pagination={false}
        scroll={scroll}
        loading={store.listStatus}
        rowSelection={rowSelection}
        columns={[...props.columns, actionColumn]}
        dataSource={dataSource}
      />
      <div style={{ textAlign: "right", padding: "10px" }}>
        <Pagination
          size="small"
          defaultCurrent={1}
          pageSize={20}
          showSizeChanger={true}
          total={store.total}
          onShowSizeChange={onShowSizeChange}
          onChange={onChange}
        />
      </div>
    </>
  );
};

export default BTable;
